<?php

namespace Drupal\cosign\CosignFunctions;

/**
 * Cosign shared functions.
 */
interface CosignSharedFunctionsInterface {

  /**
   * Check whether user is logged in.
   *
   * Determines is user is logged into cosign, is a drupal user, and is logged
   * into drupal.
   *
   * @return \Drupal\user\Entity\User
   *   User object.
   */
  public function cosignUserStatus($cosign_username);

  /**
   * Logs cosign user into drupal.
   *
   * @return \Drupal\user\Entity\User
   *   User object.
   */
  public function cosignLoginUser($drupal_user);

  /**
   * Performs tasks if friend accounts aren't allowed.
   */
  public function cosignFriendNotAllowed();

  /**
   * Returns a logout URL.
   */
  public function cosignLogoutUrl();

  /**
   * Attempts to retrieve the remote user from the $_SERVER variable.
   *
   * If the user is logged in to cosign webserver auth, the remote user variable
   * will contain the name of the user logged in.
   *
   * @return string
   *   String username or empty string.
   */
  public function cosignRetrieveRemoteUser();

  /**
   * Attempts to retrieve the protossl from the $_SERVER variable.
   *
   * We need to check for https on logins.
   * since we need to intercept redirects from routes and events, this is a
   * shared function.
   *
   * @return bool
   *   Boolean TRUE or FALSE.
   */
  public function cosignIsHttps();

  /**
   * Attempts to retrieve the remote realm from the $_SERVER variable.
   *
   * If the user is logged in to cosign webserver auth, the remote realm
   * variable will contain friend or UMICH.EDU (or some other implemetation).
   *
   * @return bool
   *   Boolean TRUE or FALSE.
   */
  public function cosignIsFriendAccount($username);

  /**
   * Creates a new drupal user.
   *
   * Creates a new drupal user with the cosign username and email address with
   * domain from admin form.
   *
   * @return \Drupal\user\Entity\User
   *   User object.
   */
  public function cosignCreateNewUser($cosign_name);

  /**
   * Used to enable the Masquerade module to play nice w/ cosign.
   *
   * Whenever we need to get the username, we check to see if we're
   * masquerading. If we are, we use the masquerade session info to select our
   * user. Otherwise, we pull the remote cosign user.
   *
   * @return string
   *   The username.
   */
  public function cosignUserMasqueradeCheck();

}
