<?php

namespace Drupal\cosign_test\CosignSharedFunctions;

use Drupal\Core\Session\AccountInterface;
use Drupal\cosign\CosignFunctions\CosignSharedFunctionsInterface;

/**
 * A stub class that allows for easily mocking the state of a cosign server.
 *
 * @package Drupal\cosign_test\CosignSharedFunctions
 */
class CosignSharedFunctionsStub implements CosignSharedFunctionsInterface {

  /**
   * The user to return from various methods.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $user;

  /**
   * Are friend accounts allowed?
   *
   * @var bool
   */
  protected $friendNotAllowed;

  /**
   * The logout url.
   *
   * @var string
   */
  protected $logoutUrl;

  /**
   * The remote user string.
   *
   * @var string
   */
  protected $remoteUser;

  /**
   * Is this an HTTPS request?
   *
   * @var bool
   */
  protected $isHttps;

  /**
   * Is the current user a friend?
   *
   * @var bool
   */
  protected $isFriendAccount;

  /**
   * Sets the user to return from various methods.
   *
   * @param \Drupal\Core\Session\AccountInterface|null $user
   *   The mock user.
   */
  public function setUser(AccountInterface $user = NULL) {
    $this->user = $user;
  }

  /**
   * Sets whether or not friends are allowed.
   *
   * @param bool $friend_not_allowed
   *   TRUE to allow friends, otherwise FALSE.
   */
  public function setFriendNotAllowed($friend_not_allowed) {
    $this->friendNotAllowed = $friend_not_allowed;
  }

  /**
   * Sets the logout url.
   *
   * @param string $logout_url
   *   The logout url.
   */
  public function setLogoutUrl($logout_url) {
    $this->logoutUrl = $logout_url;
  }

  /**
   * Sets the remote user.
   *
   * @param string $remote_user
   *   The remote user.
   */
  public function setRemoteUser($remote_user) {
    $this->remoteUser = $remote_user;
  }

  /**
   * Sets whether this is an HTTPS request or not.
   *
   * @param bool $is_https
   *   TRUE if this should be an HTTPS request, otherwise FALSE.
   */
  public function setIsHttps($is_https) {
    $this->isHttps = $is_https;
  }

  /**
   * Sets whether or not the current user is a friend.
   *
   * @param bool $is_friend_account
   *   TRUE if the user is a friend, otherwise FALSE.
   */
  public function setIsFriendAccount($is_friend_account) {
    $this->isFriendAccount = $is_friend_account;
  }

  /**
   * {@inheritdoc}
   */
  public function cosignUserStatus($cosign_username) {
    return $this->user;
  }

  /**
   * {@inheritdoc}
   */
  public function cosignLoginUser($drupal_user) {
    return $this->user;
  }

  /**
   * {@inheritdoc}
   */
  public function cosignFriendNotAllowed() {
    return $this->friendNotAllowed;
  }

  /**
   * {@inheritdoc}
   */
  public function cosignLogoutUrl() {
    return $this->logoutUrl;
  }

  /**
   * {@inheritdoc}
   */
  public function cosignRetrieveRemoteUser() {
    return $this->remoteUser;
  }

  /**
   * {@inheritdoc}
   */
  public function cosignIsHttps() {
    return $this->isHttps;
  }

  /**
   * {@inheritdoc}
   */
  public function cosignIsFriendAccount($username) {
    return $this->isFriendAccount;
  }

  /**
   * {@inheritdoc}
   */
  public function cosignCreateNewUser($cosign_name) {
    return $this->user;
  }

  /**
   * {@inheritdoc}
   */
  public function cosignUserMasqueradeCheck() {
    return $this->cosignRetrieveRemoteUser();
  }

}
